==> helm-annotations-3.2.0-sources.jar: io/dekorate/helm/config/AddIfStatementBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class AddIfStatementBuilder extends AddIfStatementFluentImpl<AddIfStatementBuilder> implements VisitableBuilder<AddIfStatement,AddIfStatementBuilder>{
  public AddIfStatementBuilder() {
    this(false);
  }
  public AddIfStatementBuilder(Boolean validationEnabled) {
    this(new AddIfStatement(), validationEnabled);
  }
  public AddIfStatementBuilder(AddIfStatementFluent<?> fluent) {
    this(fluent, false);
  }
  public AddIfStatementBuilder(AddIfStatementFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AddIfStatement(), validationEnabled);
  }
  public AddIfStatementBuilder(AddIfStatementFluent<?> fluent,AddIfStatement instance) {
    this(fluent, instance, false);
  }
  public AddIfStatementBuilder(AddIfStatementFluent<?> fluent,AddIfStatement instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProperty(instance.getProperty()); 
    fluent.withOnResourceKind(instance.getOnResourceKind()); 
    fluent.withOnResourceName(instance.getOnResourceName()); 
    fluent.withWithDefaultValue(instance.getWithDefaultValue()); 
    this.validationEnabled = validationEnabled; 
  }
  public AddIfStatementBuilder(AddIfStatement instance) {
    this(instance,false);
  }
  public AddIfStatementBuilder(AddIfStatement instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withProperty(instance.getProperty()); 
    this.withOnResourceKind(instance.getOnResourceKind()); 
    this.withOnResourceName(instance.getOnResourceName()); 
    this.withWithDefaultValue(instance.getWithDefaultValue()); 
    this.validationEnabled = validationEnabled; 
  }
  AddIfStatementFluent<?> fluent;
  Boolean validationEnabled;
  public EditableAddIfStatement build() {
    EditableAddIfStatement buildable = new EditableAddIfStatement(fluent.getProperty(),fluent.getOnResourceKind(),fluent.getOnResourceName(),fluent.getWithDefaultValue());
    return buildable;
  }
  
}

==> helm-annotations-3.5.4-sources.jar: io/dekorate/helm/config/AddIfStatementBuilder.java <==
package io.dekorate.helm.config;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;

 /**
  * Generated
  */
public class AddIfStatementBuilder extends AddIfStatementFluentImpl<AddIfStatementBuilder> implements VisitableBuilder<AddIfStatement,AddIfStatementBuilder>{
  public AddIfStatementBuilder() {
    this(false);
  }
  public AddIfStatementBuilder(Boolean validationEnabled) {
    this(new AddIfStatement(), validationEnabled);
  }
  public AddIfStatementBuilder(AddIfStatementFluent<?> fluent) {
    this(fluent, false);
  }
  public AddIfStatementBuilder(AddIfStatementFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AddIfStatement(), validationEnabled);
  }
  public AddIfStatementBuilder(AddIfStatementFluent<?> fluent,AddIfStatement instance) {
    this(fluent, instance, false);
  }
  public AddIfStatementBuilder(AddIfStatementFluent<?> fluent,AddIfStatement instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProperty(instance.getProperty()); 
    fluent.withOnResourceKind(instance.getOnResourceKind()); 
    fluent.withOnResourceName(instance.getOnResourceName()); 
    fluent.withWithDefaultValue(instance.getWithDefaultValue()); 
    fluent.withDescription(instance.getDescription()); 
    this.validationEnabled = validationEnabled; 
  }
  public AddIfStatementBuilder(AddIfStatement instance) {
    this(instance,false);
  }
  public AddIfStatementBuilder(AddIfStatement instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withProperty(instance.getProperty()); 
    this.withOnResourceKind(instance.getOnResourceKind()); 
    this.withOnResourceName(instance.getOnResourceName()); 
    this.withWithDefaultValue(instance.getWithDefaultValue()); 
    this.withDescription(instance.getDescription()); 
    this.validationEnabled = validationEnabled; 
  }
  AddIfStatementFluent<?> fluent;
  Boolean validationEnabled;
  public EditableAddIfStatement build() {
    EditableAddIfStatement buildable = new EditableAddIfStatement(fluent.getProperty(),fluent.getOnResourceKind(),fluent.getOnResourceName(),fluent.getWithDefaultValue(),fluent.getDescription());
    return buildable;
  }
  
}
